@@ -13,7 +13,7 @@ from .np import (
     rotate,
     shear,
     translate,
-    crop
+    crop,
 )
 from .tf import (
     to_tf,
@@ -22,7 +22,7 @@ from .tf import (
     tf_rotate,
     tf_shear,
     tf_translate,
-    tf_crop
+    tf_crop,
 )
 
 ORIGINAL_IMAGE_LIST = [
@@ -31,36 +31,36 @@ ORIGINAL_IMAGE_LIST = [
         [[4], [5], [6]],
         [[7], [8], [9]],
         [[10], [11], [12]]
-    ], dtype=np.float32),
+    ]),
     np.array([
         [[11], [12], [13]],
         [[14], [15], [16]],
         [[17], [18], [19]],
         [[20], [21], [22]]
-    ], dtype=np.float32),
+    ]),
     np.array([
         [[21], [22], [23]],
         [[24], [25], [26]],
         [[27], [28], [29]],
         [[30], [31], [32]]
-    ], dtype=np.float32),
+    ]),
 ]
 
 ORIGINAL_BBOXES_LIST = [
     np.array([
         [1, 0, 2, 2],
         [0, 1, 3, 2],
-    ], dtype=np.float32),
+    ]),
     np.array([
         [0, 0, 2, 3],
-    ], dtype=np.float32),
-    np.array([], dtype=np.float32).reshape(-1, 4),
+    ]),
+    np.array([]),
 ]
 
 ORIGINAL_LABELS_LIST = [
-    np.array([0, 1], dtype=np.float32),
-    np.array([2], dtype=np.float32),
-    np.array([], dtype=np.float32),
+    np.array([0, 1]),
+    np.array([2]),
+    np.array([]),
 ]
 
 (
@@ -106,7 +106,7 @@ class TestTransform(unittest.TestCase):
         ]
         expected_labels_list = ORIGINAL_LABELS_LIST
 
-        # Numpy.
+        # NumPy.
         for i in range(len(ORIGINAL_IMAGE_LIST)):
             image, bboxes, labels = flip_left_right(
                 ORIGINAL_IMAGE_LIST[i],
@@ -185,7 +185,7 @@ class TestTransform(unittest.TestCase):
         ]
         expected_labels_list = ORIGINAL_LABELS_LIST
 
-        # Numpy.
+        # NumPy.
         for i in range(len(ORIGINAL_IMAGE_LIST)):
             image, bboxes, labels = flip_up_down(
                 ORIGINAL_IMAGE_LIST[i],
@@ -279,7 +279,7 @@ class TestTransform(unittest.TestCase):
         ]
         expected_labels_list = original_labels_list
 
-        # Numpy.
+        # NumPy.
         for i in range(len(original_image_list)):
             image, bboxes, labels = rotate(
                 original_image_list[i],
@@ -349,7 +349,7 @@ class TestTransform(unittest.TestCase):
         ], dtype=np.float32)
         expected_labels = original_labels
 
-        # Numpy.
+        # NumPy.
         _, bboxes, labels = shear(
             dummy_image, original_bboxes, original_labels,
             angle_deg
@@ -419,7 +419,7 @@ class TestTransform(unittest.TestCase):
             np.array([], dtype=np.float32),
         ]
 
-        # Numpy.
+        # NumPy.
         for i in range(len(ORIGINAL_IMAGE_LIST)):
             image, bboxes, labels = translate(
                 ORIGINAL_IMAGE_LIST[i],
@@ -507,7 +507,7 @@ class TestTransform(unittest.TestCase):
             np.array([], dtype=np.float32),
         ]
 
-        # Numpy.
+        # NumPy.
         for i in range(len(dummy_image_list)):
             _, bboxes, labels = crop(
                 dummy_image_list[i],
